@@ -1245,10 +1245,103 @@ def cmd_alias(args):
         print(usage)
         return
 
-
 def cmd_arm(args):
-  '''arm motors'''
-  mpstate.master().arducopter_arm()
+    '''arm commands'''
+    usage = "usage: arm <check|uncheck|list|throttle>"
+    checkables = "<all|baro|compass|gps|ins|params|rc|voltage|battery>"
+
+    if len(args) > 0:
+        if args[0] == "check":
+            if (len(args) < 2):
+                print "usage: arm check", checkables
+                return
+            
+            arming_mask = int(mpstate.mav_param["ARMING_CHECK"])
+
+            if (args[1] == "all"):
+                arming_mask |= 0x0001
+            elif (args[1] == "baro"):
+                arming_mask |= 0x0002
+            elif (args[1] == "compass"):
+                arming_mask |= 0x0004
+            elif (args[1] == "gps"):
+                arming_mask |= 0x0008
+            elif (args[1] == "ins"):
+                arming_mask |= 0x0010
+            elif (args[1] == "params"):
+                arming_mask |= 0x0020
+            elif (args[1] == "rc"):
+                arming_mask |= 0x0030
+            elif (args[1] == "voltage"):
+                arming_mask |= 0x0040
+            elif (args[1] == "battery"):
+                arming_mask |= 0x0100
+            else:
+                print "unrecognized arm check:", args[1]
+                return
+
+            param_set("ARMING_CHECK", arming_mask)
+        elif args[0] == "uncheck":
+            if (len(args) < 2):
+                print "usage: arm uncheck", checkables
+                return
+
+            arming_mask = int(mpstate.mav_param["ARMING_CHECK"])
+
+            if (args[1] == "all"):
+                arming_mask ^= 0x0001
+            elif (args[1] == "baro"):
+                arming_mask ^= 0x0002
+            elif (args[1] == "compass"):
+                arming_mask ^= 0x0004
+            elif (args[1] == "gps"):
+                arming_mask ^= 0x0008
+            elif (args[1] == "ins"):
+                arming_mask ^= 0x0010
+            elif (args[1] == "params"):
+                arming_mask ^= 0x0020
+            elif (args[1] == "rc"):
+                arming_mask ^= 0x0040
+            elif (args[1] == "voltage"):
+                arming_mask ^= 0x0080
+            elif (args[1] == "battery"):
+                arming_mask ^= 0x0100
+            else:
+                print "unrecognized arm check:", args[1]
+                return
+
+            param_set("ARMING_CHECK", arming_mask)
+
+        elif args[0] == "list":
+            arming_mask = int(mpstate.mav_param["ARMING_CHECK"])
+            if (arming_mask & 0x0001 != 0):
+                print "ALL"
+            if (arming_mask & 0x0002 != 0):
+                print "BARO"
+            if (arming_mask & 0x0004 != 0):
+                print "COMPASS"
+            if (arming_mask & 0x0008 != 0):
+                print "GPS"
+            if (arming_mask & 0x0010 != 0):
+                print "INS"
+            if (arming_mask & 0x0020 != 0):
+                print "PARAMETERS"
+            if (arming_mask & 0x0040 != 0):
+                print "RC"
+            if (arming_mask & 0x0080 != 0):
+                print "VOLTAGE"
+            if (arming_mask & 0x0100 != 0):
+                print "BATTERY"
+
+        elif args[0] == "throttle":
+            mpstate.master().arducopter_arm()
+        else:
+            print(usage)
+            return
+    else:
+        print(usage)
+        return
+
 
 def cmd_time(args):
   '''show autopilot time'''
